
normcl
======

**angular power spectra conversions for normal random fields**

This is a minimal Python package for working with the angular power spectra of
spherical random fields constructed from normals.  It can currently convert
between the power spectra of lognormal random fields and their constituent
normal random fields.

The package can be installed using pip:

    pip install normcl

Then import the `lognormal` and `lognormal_normal` functions from the package:

    from normcl import lognormal, lognormal_normal

For more information, please see the [documentation].

Current functionality covers the absolutely minimal use case.  Please open an
issue on GitHub if you would like to see anything added.

[documentation]: https://cltools.readthedocs.io/normcl/
